@@ -9,23 +9,17 @@
 '''
 from trytond.pool import Pool
 from product import (
-    Product, BrowseNode, ProductBrowseNode, ProductsImageSet,
-    ProductUser, ProductsRelated, ProductCategory, WebSite, NereidUser,
-    WebsiteCategory, WebsiteBrowseNode
+    Product, ProductsImageSet, ProductsRelated, ProductCategory,
+    WebSite, WebsiteCategory
 )
 
 
 def register():
     Pool.register(
         Product,
-        BrowseNode,
-        ProductBrowseNode,
         ProductsImageSet,
-        ProductUser,
         ProductsRelated,
         ProductCategory,
         WebSite,
-        NereidUser,
         WebsiteCategory,
-        WebsiteBrowseNode,
         module='nereid_catalog', type_='model')
